( cd usr/lib64 ; rm -rf libXinerama.so.1 )
( cd usr/lib64 ; ln -sf libXinerama.so.1.0.0 libXinerama.so.1 )
( cd usr/lib64 ; rm -rf libXinerama.so )
( cd usr/lib64 ; ln -sf libXinerama.so.1.0.0 libXinerama.so )
